#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 weigh
version:              0.0.16
visibility:           public
id:                   weigh-0.0.16-5qRjkjSBOBa2ARTL08GDHz
key:                  weigh-0.0.16-5qRjkjSBOBa2ARTL08GDHz
license:              BSD-3-Clause
copyright:            FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
homepage:             https://github.com/fpco/weigh#readme
synopsis:             Measure allocations of a Haskell functions/values
description:          Please see README.md
category:             Web
abi:                  2c1654e4c0f9ea8ef56ad4b2e8c0def8
exposed:              True
exposed-modules:      Weigh
hidden-modules:       Weigh.GHCStats
import-dirs:          /usr/lib/ghc-8.10.5/site-local/weigh-0.0.16
library-dirs:         /usr/lib/ghc-8.10.5/site-local/weigh-0.0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/weigh-0.0.16
hs-libraries:         HSweigh-0.0.16-5qRjkjSBOBa2ARTL08GDHz
depends:
    base-4.14.2.0 deepseq-1.4.4.0 ghc-8.10.5 mtl-2.2.2 process-1.6.9.0
    split-0.2.3.4-6NNts3pcZSB6Io5fuJ9m3X
    temporary-1.3-2IjA4J7jKmb3rvOA3dYC2H

haddock-interfaces:   /usr/share/doc/haskell-weigh/html/weigh.haddock
haddock-html:         /usr/share/doc/haskell-weigh/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

